.. image:: https://travis-ci.org/nose-devs/nose2.svg?branch=master
    :target: https://travis-ci.org/nose-devs/nose2
    :alt: Build Status

.. image:: https://coveralls.io/repos/github/nose-devs/nose2/badge.svg?branch=master
    :target: https://coveralls.io/github/nose-devs/nose2?branch=master
    :alt: Coverage Status

.. image:: https://img.shields.io/pypi/v/nose2.svg
    :target: https://pypi.org/project/nose2/
    :alt: Latest PyPI version

 [![Google group : SSFAM News](https://img.shields.io/badge/Google%20Group-SSFAM%20News-blue.svg)](https://groups.google.com/forum/#!forum/ssfam-news)
.. image:: https://img.shields.io/badge/Mailing%20list-discuss%40nose2.io-blue.svg
    :target: https://groups.google.com/a/nose2.io/forum/#!forum/discuss
    :alt: Join discuss@nose2.io

Welcome to nose2
================

``nose2`` is the successor to ``nose``.

It's ``unittest`` with plugins.

``nose2`` is a new project and does not support all of the features of
``nose``. See `differences`_ for a thorough rundown.

nose2's purpose is to extend ``unittest`` to make testing nicer and easier to
understand.

nose2 vs pytest
---------------

``nose2`` may or may not be a good fit for your project.

If you are new to python testing, we encourage you to also consider `pytest`_,
a popular testing framework.

Full Docs
---------

Full documentation for ``nose2`` is available at _nose2docs

Contributing
------------

If you want to make contributions, please read the `contributing`_ guide.

.. _differences: https://nose2.readthedocs.io/en/latest/differences.html

.. _pytest: http://pytest.readthedocs.io/en/latest/

.. _contributing: https://github.com/nose-devs/nose2/blob/master/contributing.rst

.. _nose2docs: https://docs.nose2.io/en/latest/
